@@ -31,14 +31,20 @@ class TokenType(Enum):
     # functions returning string
     LOWER = 54
     UPPER = 55
+    # function returning number
+    LEN = 56
 
 
 class Token:
-    def __init__(self, ttext, ttype):
+    def __init__(self, ttext, ttype, start_pos=None, end_pos=None):
         # token text for token types VARIABLE, STRING and NUMBER is
         # necessary; for other token types it is kind-of redundant
         self.ttext = ttext
         self.ttype = ttype
+        # Gives start and end position of token in expression if it is a variables
+        # For expression "de" == ${conv.lang}
+        self.start_pos = start_pos
+        self.end_pos = end_pos
 
     token_map = {
         "and": TokenType.AND,
@@ -51,6 +57,7 @@ class Token:
         "endswith": TokenType.ENDSWITH,
         "lower": TokenType.LOWER,
         "upper": TokenType.UPPER,
+        "len": TokenType.LEN,
     }
 
     @staticmethod
